=========================================
sve_common_tools
=========================================

.. sectnum::

.. contents:: Indice

Sve_SSHManager
~~~~~~~~~~~~~~~~~~~~~~~~~

Classe di gestione SSH tramite paramiko

Sve_file_utils
~~~~~~~~~~~~~~~~~~~~~~~~~

Classe di gestione operazioni su blocchi di testo
 - def strip_rows(command_output)
 - def remove_skip_rows(multiline_str, skip_str_array, skip_empty_lines)
 - def check_header_string_regexp_array(multiline_str, header_str_regexp_array)
 - def check_header_string_array(multiline_str, header_str_array)
 - def remove_before_header_string(multiline_str, header_str)
 - def remove_after_footer_string(multiline_str, footer_str)
 - def extract_block(multiline_str, starting_row, ending_row, add_ending_row)
 - def add_char_to_every_row_if_not_exist(multiline_str, character)
 - def parse_extact_table(multiline_str, header_column_position)
 - def create_htmltable(command_output_array_table, first_row_html_header)

